#!/usr/bin/env python

import sys,os
import Gnuplot

def sort_files(files):

    result = []

    for entry in range(0, len(files)-1):
        result.append("")
   
    for file in files:

        if "xenperf" not in file:
            continue
        
        parts = file.split("_")
        nr = parts[1]
        result[int(nr)-1] = file

    return result


def line_get_number(line):
    line = line.strip()
    while "  " in line:
        line = line.replace("  ", " ")

    parts = line.split(" ")

    return int(parts[-2])


def get_max(arg, files):

    max = 0

    for file in files:
        
        result_set = open(arg + "/" + file, "r")
        
        for l in result_set.readlines():
            if "reclaimed total" in l:
                tmp = line_get_number(l)
                if tmp > max:
                    max = tmp
    return max

def do_plot(maxes):
    output = "allocation" + str(len(maxes)) +  ".pdf"

    Gnuplot.GnuplotOpts.default_term = "pdf"
    g = Gnuplot.Gnuplot(debug=0)
    
    g('set output "' + output + '"')

    g('set terminal pdf fsize 10')
    
    g.xlabel("VM Memory Allocation (MB)")
    g.ylabel("Memory (Pages)")
    g("set xrange [0:1.6]")
    g("set yrange [0:80000]")

    g('unset key')
    g("set boxwidth 0.10")
    g("set style fill solid 1.200000 border -1")
    g('set xtics nomirror ("64" 0.2, "128" 0.4, "192" 0.6, "256" 0.8, "320" 1.0, "384" 1.2, "448" 1.4)')

    x = [0.2, 0.4, 0.6, 0.8, 1.0, 1.2, 1.4]

    d1 = Gnuplot.Data(x, maxes, with='boxes lc rgb "' + colour + '"')

    g.plot(d1)

def do_plot_percentage(maxes):
    output = "allocation_percentage" + str(len(maxes)) +  ".pdf"

    Gnuplot.GnuplotOpts.default_term = "pdf"
    g = Gnuplot.Gnuplot(debug=0)
    
    g('set output "' + output + '"')

    g('set terminal pdf fsize 10')
    
    g.xlabel("VM Memory Allocation (MB)")
    g.ylabel("VM Memory (%)")
    g("set xrange [0:1.6]")
    g("set yrange [0:]")

    g('unset key')
    g("set boxwidth 0.10")
    g("set style fill solid 1.200000 border -1")
    g('set xtics nomirror ("64" 0.2, "128" 0.4, "192" 0.6, "256" 0.8, "320" 1.0, "384" 1.2, "448" 1.4)')

    x = [0.2, 0.4, 0.6, 0.8, 1.0, 1.2, 1.4]
    size = [64,128,192,256,320,384,448]

    per = []

    count = -1
    for e in maxes:
        count += 1
        vm_pages = size[count] * 1024 *1024 / 4096.0
        per.append((e / (4 * vm_pages)) * 100)
        
    d1 = Gnuplot.Data(x, per, with='boxes lc rgb "' + colour + '"')

    g.plot(d1)

#colour = "#3a3aab"
colour = "#8888db"
maxes = []

for arg in sys.argv[1:]:
    files = os.listdir(arg)
    files = sort_files(files)
    l = get_max(arg, files)
    maxes.append(l)

do_plot(maxes)
do_plot_percentage(maxes)
